=============================================================
``psyclone.domain.lfric.transformations.lfric_extract_trans``
=============================================================

.. automodule:: psyclone.domain.lfric.transformations.lfric_extract_trans

   .. contents::
      :local:

.. currentmodule:: psyclone.domain.lfric.transformations.lfric_extract_trans
